<?php
session_start();

// 初始化新闻存储数组
if (!isset($_SESSION['news'])) {
    $_SESSION['news'] = [];
}

// 处理删除请求
if (isset($_GET['action']) && $_GET['action'] === 'delete' && isset($_GET['id'])) {
    $id = $_GET['id'];
    if (isset($_SESSION['news'][$id])) {
        unset($_SESSION['news'][$id]);
    }
    header('Location: ' . $_SERVER['PHP_SELF']);
    exit;
}

// 处理表单提交
if ($_SERVER['REQUEST_METHOD'] === 'POST') {
    $title = trim($_POST['title'] ?? '');
    $content = trim($_POST['content'] ?? '');
    $categories = $_POST['categories'] ?? [];

    if (!empty($title) && !empty($content) && !empty($categories)) {
        $id = uniqid();
        $_SESSION['news'][$id] = [
            'title' => $title,
            'content' => $content,
            'categories' => $categories,
            'time' => date('Y-m-d H:i:s')
        ];
    }
}
?>

<!DOCTYPE html>
<html lang="zh-CN">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>新闻发布系统</title>
    <link href="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/css/bootstrap.min.css" rel="stylesheet">
    <style>
        :root {
            --primary-color: #2c3e50;
            --secondary-color: #3498db;
            --success-color: #27ae60;
            --danger-color: #e74c3c;
        }

        body {
            background-color: #f8f9fa;
            min-height: 100vh;
        }

        .news-card {
            transition: transform 0.3s ease, box-shadow 0.3s ease;
            border: none;
            border-radius: 12px;
            background: linear-gradient(145deg, #ffffff, #f8f9fa);
            box-shadow: 0 4px 6px rgba(0, 0, 0, 0.05);
        }

        .news-card:hover {
            transform: translateY(-5px);
            box-shadow: 0 8px 15px rgba(0, 0, 0, 0.1);
        }

        .category-badge {
            background-color: var(--secondary-color);
            color: white;
            padding: 5px 12px;
            border-radius: 20px;
            font-size: 0.9em;
        }

        .delete-btn {
            transition: all 0.3s ease;
            color: var(--danger-color);
            border: 2px solid var(--danger-color);
            padding: 5px 15px;
            border-radius: 25px;
            text-decoration: none;
        }

        .delete-btn:hover {
            background-color: var(--danger-color);
            color: white;
        }

        .main-container {
            max-width: 800px;
            margin: 0 auto;
            padding: 2rem;
        }

        .time-stamp {
            color: #95a5a6;
            font-size: 0.9em;
        }

        .gradient-header {
            background: linear-gradient(135deg, var(--primary-color), var(--secondary-color));
            color: white;
            padding: 2rem;
            border-radius: 12px;
            margin-bottom: 2rem;
        }

        .form-control-custom {
            border: 2px solid #e0e0e0;
            border-radius: 8px;
            padding: 12px;
            transition: border-color 0.3s ease;
        }

        .form-control-custom:focus {
            border-color: var(--secondary-color);
            box-shadow: none;
        }

        .form-check-label {
            user-select: none;
        }

        .submit-btn {
            background-color: var(--success-color);
            color: white;
            padding: 12px 30px;
            border: none;
            border-radius: 25px;
            font-weight: bold;
            transition: transform 0.2s ease;
        }

        .submit-btn:hover {
            transform: scale(1.05);
        }
    </style>
</head>
<body>
<nav class="navbar navbar-dark bg-primary">
    <div class="container">
        <a class="navbar-brand" href="#">新闻发布系统</a>
    </div>
</nav>

<div class="main-container">
    <div class="gradient-header text-center">
        <h1>发布新闻</h1>
        <p class="mb-0">分享最新资讯</p>
    </div>

    <form method="post" class="bg-white p-4 rounded-3 shadow-sm mb-5">
        <div class="mb-4">
            <label class="form-label fw-bold">标题</label>
            <input type="text" name="title" class="form-control form-control-custom" required>
        </div>

        <div class="mb-4">
            <label class="form-label fw-bold">内容</label>
            <textarea name="content" class="form-control form-control-custom" rows="4" required></textarea>
        </div>

        <div class="mb-4">
            <label class="form-label fw-bold">选择类别</label>
            <div class="d-flex flex-wrap gap-3">
                <div class="form-check">
                    <input class="form-check-input" type="checkbox" name="categories[]" value="科技" id="tech">
                    <label class="form-check-label" for="tech">科技</label>
                </div>
                <div class="form-check">
                    <input class="form-check-input" type="checkbox" name="categories[]" value="体育" id="sports">
                    <label class="form-check-label" for="sports">体育</label>
                </div>
                <div class="form-check">
                    <input class="form-check-input" type="checkbox" name="categories[]" value="娱乐" id="entertainment">
                    <label class="form-check-label" for="entertainment">娱乐</label>
                </div>
                <div class="form-check">
                    <input class="form-check-input" type="checkbox" name="categories[]" value="财经" id="finance">
                    <label class="form-check-label" for="finance">财经</label>
                </div>
            </div>
        </div>

        <div class="text-center">
            <button type="submit" class="submit-btn">发布新闻</button>
        </div>
    </form>

    <h2 class="mb-4 fw-bold text-primary">最新动态</h2>

    <?php foreach ($_SESSION['news'] as $id => $news): ?>
        <div class="news-card mb-4 p-4">
            <div class="d-flex justify-content-between align-items-start mb-3">
                <h3 class="mb-0 fw-bold"><?php echo htmlspecialchars($news['title']); ?></h3>
                <a href="?action=delete&id=<?php echo $id; ?>" class="delete-btn">删除</a>
            </div>
            <p class="text-muted mb-3"><?php echo nl2br(htmlspecialchars($news['content'])); ?></p>
            <div class="d-flex flex-wrap gap-2 align-items-center">
                <?php foreach ($news['categories'] as $category): ?>
                    <span class="category-badge"><?php echo htmlspecialchars($category); ?></span>
                <?php endforeach; ?>
                <span class="time-stamp ms-auto"><?php echo $news['time']; ?></span>
            </div>
        </div>
    <?php endforeach; ?>
</div>

<footer class="bg-light text-center py-3 mt-5">
    <div class="container">
        <span class="text-muted">© 2023 新闻发布系统 版权所有</span>
    </div>
</footer>

<script src="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/js/bootstrap.bundle.min.js"></script>
</body>
</html>
